@@ -22,7 +22,7 @@ class Parser:
         params = {'access_token': token, 'code': code, 'v': self.v}
         async with aiohttp.ClientSession() as session:
             async with session.get(url=url, params=params) as resp:
-                response = await resp.json()
+                response = await resp.json(content_type='text/html')
 
         delay = 1 / 2.9 - (time.time() - ts)
         if delay > 0:
@@ -57,12 +57,11 @@ class Parser:
         items_per_acc = math.ceil(len(items) / len(self.tokens))
         account_items = [items[i:i+items_per_acc] for i in range(0, len(items), items_per_acc)]
 
+        loop = asyncio.new_event_loop()
+        tasks = [loop.create_task(self.parse_items(t, method, i)) for t, i in zip(self.tokens, account_items)]
+        loop.run_until_complete(asyncio.wait(tasks))
 
-        ioloop = asyncio.new_event_loop()
-        tasks = [ioloop.create_task(self.parse_items(t, method, i)) for t, i in zip(self.tokens, account_items)]
-        ioloop.run_until_complete(asyncio.wait(tasks))
-        ioloop.close()
-
+        loop.close()
         result = []
         for t in tasks:
             result.extend(t.result())
